@@ -36,7 +36,8 @@ st_combine(nc)
 st_dimension(st_sfc(st_point(0:1), st_linestring(rbind(c(0,0),c(1,1))), 
 	st_polygon(list(rbind(c(0,0), c(1,0), c(1,1), c(0,1), c(0,0))))))
 
-g = st_make_grid(nc)
+ncbb = st_as_sfc(st_bbox(nc))
+g = st_make_grid(ncbb)
 x = st_intersection(nc, g)
 x = st_intersection(g, nc)
 
@@ -48,7 +49,7 @@ set.seed(13531)
 
 st_line_sample(ls, density = 1, type = "random")
 
-g = st_make_grid(nc, n = c(20,10))
+g = st_make_grid(ncbb, n = c(20,10))
 
 a1 = st_interpolate_aw(nc["BIR74"], g, FALSE)
 sum(a1$BIR74) / sum(nc$BIR74) # not close to one: property is assumed spatially intensive
@@ -62,8 +63,8 @@ length(g)
 g = st_make_grid(what = "corners")
 length(g)
 
-g1 = st_make_grid(nc, 0.1, what = "polygons", square = FALSE)
-g2 = st_make_grid(nc, 0.1, what = "points", square = FALSE)
+g1 = st_make_grid(ncbb, 0.1, what = "polygons", square = FALSE)
+g2 = st_make_grid(ncbb, 0.1, what = "points", square = FALSE)
 
 # st_line_merge:
 mls = st_multilinestring(list(rbind(c(0,0), c(1,1)), rbind(c(2,0), c(1,1))))
@@ -93,7 +94,7 @@ i = st_intersects(ncm, ncm[1:88,])
 all.equal(i, t(t(i)))
 
 # check use of pattern in st_relate:
-sfc = st_sfc(st_point(c(0,0)), st_point(c(3,3)))
+sfc = st_as_sfc(st_bbox(st_sfc(st_point(c(0,0)), st_point(c(3,3)))))
 grd = st_make_grid(sfc, n = c(3,3))
 st_intersects(grd)
 st_relate(grd, pattern = "****1****")
@@ -120,8 +121,10 @@ x = st_is_within_distance(nc_3857, nc_3857, 100000)
 y = st_is_within_distance(nc_3857, nc_3857, units::set_units(100, km))
 all.equal(x, y)
 
+pe = st_sfc(st_point())
 p = st_sfc(st_point(c(0,0)), st_point(c(0,1)), st_point(c(0,2)))
 st_distance(p, p)
+st_distance(p, pe)
 st_distance(p, p, by_element = TRUE)
 st_crs(p) = 4326
 st_distance(p, p[c(2,3,1)], by_element = TRUE)
@@ -166,7 +169,8 @@ B = st_as_sfc("LINESTRING (0 100, 0 10, 80 10)")
 st_distance(c(A,B))
 st_distance(c(A,B), which = "Hausdorff")
 st_distance(c(A,B), which = "Hausdorff", par = 0.001)
-
+LE = st_as_sfc("LINESTRING EMPTY")
+st_distance(c(A, LE), which = "Hausdorff", par = 0.001)
 
 # one-argument st_intersection and st_difference:
 set.seed(131)
@@ -253,3 +257,22 @@ sf:::is_symmetric(pattern = "010121010")
 sf:::is_symmetric(pattern = "010121021")
 
 st_intersects(st_point(0:1), st_point(2:3)) # sfg method
+
+if (sf_extSoftVersion()["GEOS"] >= "3.7.0") {
+	ls = st_linestring(rbind(c(1,1), c(2,2), c(3,3)))
+	print(st_reverse(ls))
+	print(st_reverse(st_sfc(ls)))
+	print(st_reverse(st_sf(a = 2, geom = st_sfc(ls))))
+}
+
+p = st_polygon(list(rbind(c(0,0), c(1,0), c(1,1), c(0,1), c(0,0))))
+y = st_sfc(p)
+x = st_sfc(p + 1.001)
+
+x %>% st_set_precision(0) %>% st_intersects(y)
+x %>% st_set_precision(10000) %>% st_intersects(y)
+x %>% st_set_precision(1000) %>% st_intersects(y)
+x %>% st_set_precision(501) %>% st_intersects(y) # no
+x %>% st_set_precision(500) %>% st_intersects(y) # yes
+x %>% st_set_precision(100) %>% st_intersects(y)
+x %>% st_set_precision(10) %>% st_intersects(y)
